@@ -13,4 +13,4 @@ GNU General Public License for more details.
 
 For detail about GNU see <http://www.gnu.org/licenses/>.
 '''
-from .router import RoutingNoWindException, RoutingResult
\ No newline at end of file
+from .router import RoutingNoWindException, RoutingResult, IsoPoint
\ No newline at end of file
